# Changelog

All notable changes to this project will be documented in this file.

## [Unreleased]

## [0.0.1] - 2023-03-06

- Initial release

[unreleased]: https://github.com/Strixx76/pywam
[0.0.1]: https://github.com/Strixx76/pywam/tree/v0.0.1
